@@ -1,5 +1,4 @@
 from typing import Union
-from .utils import *
 
 class NoCategoryError(Exception):
     """
@@ -7,7 +6,7 @@ class NoCategoryError(Exception):
 
     Parameters:
         * `target_category`: Non-existant input category that causes error.
-            - type: str
+            - type: string
     """
 
     def __init__(self, target_category: str):
@@ -20,10 +19,10 @@ class NoEntryError(Exception):
 
     Parameters:
         * `target_entry`: Non-existant input entry that causes error.
-            - type: str, int
+            - type: string, int
     """
 
-    def __init__(self, target_entry: types.entry):
+    def __init__(self, target_entry: Union[str, int]):
         self.target_entry = target_entry
 
         self.message: str
